@@ -124,12 +124,14 @@ class HashableNDArray:
 
         self.__tight = tight
         self.__wrapped = np.array(wrapped) if tight else wrapped
-        self.__hash = int(sha1(wrapped.view()).hexdigest(), 16)
+        self.__hash = int(sha1(wrapped.view()).hexdigest(), 16)  # nosec
 
     def __eq__(self, other) -> bool:
+        """Performs equality of the underlying array."""
         return np.all(self.__wrapped == other.__wrapped)
 
     def __hash__(self) -> int:
+        """Return the hash of the array."""
         return self.__hash
 
     def unwrap(self) -> np.ndarray:
@@ -266,7 +268,7 @@ def convert_bytes_to_string(data: Union[bytes, bytearray, Text]) -> Text:
 
 def get_file_hash(path: Text) -> Text:
     """Calculate the md5 hash of a file."""
-    return md5(file_as_bytes(path)).hexdigest()
+    return md5(file_as_bytes(path)).hexdigest()  # nosec
 
 
 async def download_file_from_url(url: Text) -> Text:
